@@ -30,8 +30,8 @@ set_formatter.__rich_repr__ = old_set_formatter.__rich_repr__
 helpers["set_formatter"] = set_formatter
 Friendly.set_formatter = set_formatter  # noqa
 
-old_light = light
-old_dark = dark
+old_light = light  # noqa
+old_dark = dark  # noqa
 
 
 def light():
@@ -45,13 +45,13 @@ def dark():
 light.help = old_light.help  # noqa
 light.__rich_repr__ = old_light.__rich_repr__  # noqa
 light.__doc__ = old_light.__doc__
-Friendly.light = light
+Friendly.light = light  # noqa
 helpers["light"] = light
 
 dark.help = old_dark.help  # noqa
 dark.__rich_repr__ = old_dark.__rich_repr__  # noqa
 dark.__doc__ = old_dark.__doc__
-Friendly.dark = dark
+Friendly.dark = dark  # noqa
 helpers["dark"] = dark
 
 
