@@ -63,7 +63,7 @@ def jupyter_interactive(info, include="friendly_tb"):  # noqa
 def add_message(info, count=-1):
     old_jupyter_html_format = rich_jupyter.JUPYTER_HTML_FORMAT
     rich_jupyter.JUPYTER_HTML_FORMAT = (
-        "<div id='friendly-message{count}'>".format(count=COUNT)
+        "<div id='friendly-message{count}'>".format(count=count)
         + old_jupyter_html_format
         + "</div>"
     )
